# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 62.0.9-v202311011323
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class RemoteAgentStatusOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'available_versions': 'list[str]',
        'base_version': 'str',
        'current_version': 'str',
        'free_disk_space': 'int',
        'name': 'str',
        'pending_progress': 'float',
        'pending_status': 'str',
        'pending_version': 'str',
        'platform': 'str',
        'platform_architecture': 'str',
        'platform_version': 'str',
        'status': 'str',
        'status_received_time': 'int',
        'updates_enabled': 'bool'
    }

    attribute_map = {
        'available_versions': 'availableVersions',
        'base_version': 'baseVersion',
        'current_version': 'currentVersion',
        'free_disk_space': 'freeDiskSpace',
        'name': 'name',
        'pending_progress': 'pendingProgress',
        'pending_status': 'pendingStatus',
        'pending_version': 'pendingVersion',
        'platform': 'platform',
        'platform_architecture': 'platformArchitecture',
        'platform_version': 'platformVersion',
        'status': 'status',
        'status_received_time': 'statusReceivedTime',
        'updates_enabled': 'updatesEnabled'
    }

    def __init__(self, available_versions=None, base_version=None, current_version=None, free_disk_space=None, name=None, pending_progress=None, pending_status=None, pending_version=None, platform=None, platform_architecture=None, platform_version=None, status=None, status_received_time=None, updates_enabled=False):
        """
        RemoteAgentStatusOutputV1 - a model defined in Swagger
        """

        self._available_versions = None
        self._base_version = None
        self._current_version = None
        self._free_disk_space = None
        self._name = None
        self._pending_progress = None
        self._pending_status = None
        self._pending_version = None
        self._platform = None
        self._platform_architecture = None
        self._platform_version = None
        self._status = None
        self._status_received_time = None
        self._updates_enabled = None

        if available_versions is not None:
          self.available_versions = available_versions
        if base_version is not None:
          self.base_version = base_version
        if current_version is not None:
          self.current_version = current_version
        if free_disk_space is not None:
          self.free_disk_space = free_disk_space
        if name is not None:
          self.name = name
        if pending_progress is not None:
          self.pending_progress = pending_progress
        if pending_status is not None:
          self.pending_status = pending_status
        if pending_version is not None:
          self.pending_version = pending_version
        if platform is not None:
          self.platform = platform
        if platform_architecture is not None:
          self.platform_architecture = platform_architecture
        if platform_version is not None:
          self.platform_version = platform_version
        if status is not None:
          self.status = status
        if status_received_time is not None:
          self.status_received_time = status_received_time
        if updates_enabled is not None:
          self.updates_enabled = updates_enabled

    @property
    def available_versions(self):
        """
        Gets the available_versions of this RemoteAgentStatusOutputV1.
        All versions that have been unpacked on the remote agent

        :return: The available_versions of this RemoteAgentStatusOutputV1.
        :rtype: list[str]
        """
        return self._available_versions

    @available_versions.setter
    def available_versions(self, available_versions):
        """
        Sets the available_versions of this RemoteAgentStatusOutputV1.
        All versions that have been unpacked on the remote agent

        :param available_versions: The available_versions of this RemoteAgentStatusOutputV1.
        :type: list[str]
        """

        self._available_versions = available_versions

    @property
    def base_version(self):
        """
        Gets the base_version of this RemoteAgentStatusOutputV1.
        The version installed by executing the installer, usually to a admin protected location. For example the installation located in C:\\Program Files\\ on Windows

        :return: The base_version of this RemoteAgentStatusOutputV1.
        :rtype: str
        """
        return self._base_version

    @base_version.setter
    def base_version(self, base_version):
        """
        Sets the base_version of this RemoteAgentStatusOutputV1.
        The version installed by executing the installer, usually to a admin protected location. For example the installation located in C:\\Program Files\\ on Windows

        :param base_version: The base_version of this RemoteAgentStatusOutputV1.
        :type: str
        """

        self._base_version = base_version

    @property
    def current_version(self):
        """
        Gets the current_version of this RemoteAgentStatusOutputV1.
        The version currently running on the remote agent

        :return: The current_version of this RemoteAgentStatusOutputV1.
        :rtype: str
        """
        return self._current_version

    @current_version.setter
    def current_version(self, current_version):
        """
        Sets the current_version of this RemoteAgentStatusOutputV1.
        The version currently running on the remote agent

        :param current_version: The current_version of this RemoteAgentStatusOutputV1.
        :type: str
        """

        self._current_version = current_version

    @property
    def free_disk_space(self):
        """
        Gets the free_disk_space of this RemoteAgentStatusOutputV1.
        Amount of free space in bytes on the drive containing the data folder of the remote agent

        :return: The free_disk_space of this RemoteAgentStatusOutputV1.
        :rtype: int
        """
        return self._free_disk_space

    @free_disk_space.setter
    def free_disk_space(self, free_disk_space):
        """
        Sets the free_disk_space of this RemoteAgentStatusOutputV1.
        Amount of free space in bytes on the drive containing the data folder of the remote agent

        :param free_disk_space: The free_disk_space of this RemoteAgentStatusOutputV1.
        :type: int
        """

        self._free_disk_space = free_disk_space

    @property
    def name(self):
        """
        Gets the name of this RemoteAgentStatusOutputV1.
        Name of the remote agent; composed of the hostname and the installation suffix

        :return: The name of this RemoteAgentStatusOutputV1.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this RemoteAgentStatusOutputV1.
        Name of the remote agent; composed of the hostname and the installation suffix

        :param name: The name of this RemoteAgentStatusOutputV1.
        :type: str
        """

        self._name = name

    @property
    def pending_progress(self):
        """
        Gets the pending_progress of this RemoteAgentStatusOutputV1.
        The progress of downloading and extracting the pending version; A number between 0 and 1 inclusive where 0 indicates 0% complete and 1 indicates 100% complete

        :return: The pending_progress of this RemoteAgentStatusOutputV1.
        :rtype: float
        """
        return self._pending_progress

    @pending_progress.setter
    def pending_progress(self, pending_progress):
        """
        Sets the pending_progress of this RemoteAgentStatusOutputV1.
        The progress of downloading and extracting the pending version; A number between 0 and 1 inclusive where 0 indicates 0% complete and 1 indicates 100% complete

        :param pending_progress: The pending_progress of this RemoteAgentStatusOutputV1.
        :type: float
        """

        self._pending_progress = pending_progress

    @property
    def pending_status(self):
        """
        Gets the pending_status of this RemoteAgentStatusOutputV1.
        The current stage of a pending downloading and extracting on a remote agent

        :return: The pending_status of this RemoteAgentStatusOutputV1.
        :rtype: str
        """
        return self._pending_status

    @pending_status.setter
    def pending_status(self, pending_status):
        """
        Sets the pending_status of this RemoteAgentStatusOutputV1.
        The current stage of a pending downloading and extracting on a remote agent

        :param pending_status: The pending_status of this RemoteAgentStatusOutputV1.
        :type: str
        """
        allowed_values = ["NONE", "DOWNLOADING", "EXTRACTING", "SUCCESS", "RESTART", "ERROR"]
        if pending_status not in allowed_values:
            raise ValueError(
                "Invalid value for `pending_status` ({0}), must be one of {1}"
                .format(pending_status, allowed_values)
            )

        self._pending_status = pending_status

    @property
    def pending_version(self):
        """
        Gets the pending_version of this RemoteAgentStatusOutputV1.
        The version currently downloading and/or extracting on the remote agent

        :return: The pending_version of this RemoteAgentStatusOutputV1.
        :rtype: str
        """
        return self._pending_version

    @pending_version.setter
    def pending_version(self, pending_version):
        """
        Sets the pending_version of this RemoteAgentStatusOutputV1.
        The version currently downloading and/or extracting on the remote agent

        :param pending_version: The pending_version of this RemoteAgentStatusOutputV1.
        :type: str
        """

        self._pending_version = pending_version

    @property
    def platform(self):
        """
        Gets the platform of this RemoteAgentStatusOutputV1.
        Operating system of the remote agent; linux or windows

        :return: The platform of this RemoteAgentStatusOutputV1.
        :rtype: str
        """
        return self._platform

    @platform.setter
    def platform(self, platform):
        """
        Sets the platform of this RemoteAgentStatusOutputV1.
        Operating system of the remote agent; linux or windows

        :param platform: The platform of this RemoteAgentStatusOutputV1.
        :type: str
        """

        self._platform = platform

    @property
    def platform_architecture(self):
        """
        Gets the platform_architecture of this RemoteAgentStatusOutputV1.
        Architecture of platform; 32bits or 64bits

        :return: The platform_architecture of this RemoteAgentStatusOutputV1.
        :rtype: str
        """
        return self._platform_architecture

    @platform_architecture.setter
    def platform_architecture(self, platform_architecture):
        """
        Sets the platform_architecture of this RemoteAgentStatusOutputV1.
        Architecture of platform; 32bits or 64bits

        :param platform_architecture: The platform_architecture of this RemoteAgentStatusOutputV1.
        :type: str
        """

        self._platform_architecture = platform_architecture

    @property
    def platform_version(self):
        """
        Gets the platform_version of this RemoteAgentStatusOutputV1.
        Version and distribution of platform; Ubuntu 20.04, Windows Server 2019, etc

        :return: The platform_version of this RemoteAgentStatusOutputV1.
        :rtype: str
        """
        return self._platform_version

    @platform_version.setter
    def platform_version(self, platform_version):
        """
        Sets the platform_version of this RemoteAgentStatusOutputV1.
        Version and distribution of platform; Ubuntu 20.04, Windows Server 2019, etc

        :param platform_version: The platform_version of this RemoteAgentStatusOutputV1.
        :type: str
        """

        self._platform_version = platform_version

    @property
    def status(self):
        """
        Gets the status of this RemoteAgentStatusOutputV1.
        Free form text description of the current stage of the remote agent. If the pending version couldn't be downloaded or extracted then the status should include the error or reason that it couldn't be completed and if the operation will be retried

        :return: The status of this RemoteAgentStatusOutputV1.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this RemoteAgentStatusOutputV1.
        Free form text description of the current stage of the remote agent. If the pending version couldn't be downloaded or extracted then the status should include the error or reason that it couldn't be completed and if the operation will be retried

        :param status: The status of this RemoteAgentStatusOutputV1.
        :type: str
        """

        self._status = status

    @property
    def status_received_time(self):
        """
        Gets the status_received_time of this RemoteAgentStatusOutputV1.
        Time when the status was last received

        :return: The status_received_time of this RemoteAgentStatusOutputV1.
        :rtype: int
        """
        return self._status_received_time

    @status_received_time.setter
    def status_received_time(self, status_received_time):
        """
        Sets the status_received_time of this RemoteAgentStatusOutputV1.
        Time when the status was last received

        :param status_received_time: The status_received_time of this RemoteAgentStatusOutputV1.
        :type: int
        """

        self._status_received_time = status_received_time

    @property
    def updates_enabled(self):
        """
        Gets the updates_enabled of this RemoteAgentStatusOutputV1.
        True if remote agent has the remote update feature enabled

        :return: The updates_enabled of this RemoteAgentStatusOutputV1.
        :rtype: bool
        """
        return self._updates_enabled

    @updates_enabled.setter
    def updates_enabled(self, updates_enabled):
        """
        Sets the updates_enabled of this RemoteAgentStatusOutputV1.
        True if remote agent has the remote update feature enabled

        :param updates_enabled: The updates_enabled of this RemoteAgentStatusOutputV1.
        :type: bool
        """

        self._updates_enabled = updates_enabled

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, RemoteAgentStatusOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 62.0.9-v202311011323
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import sys
import os
import re

# python 2 and python 3 compatibility library
from six import iteritems

from ..configuration import Configuration
from ..api_client import ApiClient
from ..models import *

class UserGroupsApi(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        config = Configuration()
        if api_client:
            self.api_client = api_client
        else:
            if not config.api_client:
                config.api_client = ApiClient()
            self.api_client = config.api_client

    def add_identity_to_user_group(self, **kwargs):
        """
        Add a user to a user group
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.add_identity_to_user_group(user_group_id=user_group_id_value, identity_id=identity_id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str user_group_id: ID of the user group to add user or user group to (required)
        :param str identity_id: ID of the user or user group to add. (required)
        :return: UserGroupOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: UserGroupOutputV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.add_identity_to_user_group_with_http_info(**kwargs)
        else:
            (data) = self.add_identity_to_user_group_with_http_info(**kwargs)
            return data

    def add_identity_to_user_group_with_http_info(self, **kwargs):
        """
        Add a user to a user group
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.add_identity_to_user_group_with_http_info(user_group_id=user_group_id_value, identity_id=identity_id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str user_group_id: ID of the user group to add user or user group to (required)
        :param str identity_id: ID of the user or user group to add. (required)
        :return: UserGroupOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: UserGroupOutputV1
        """

        all_params = ['user_group_id', 'identity_id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method add_identity_to_user_group" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'user_group_id' is set
        if ('user_group_id' not in params) or (params['user_group_id'] is None):
            raise ValueError("Missing the required parameter `user_group_id` when calling `add_identity_to_user_group`")
        # verify the required parameter 'identity_id' is set
        if ('identity_id' not in params) or (params['identity_id'] is None):
            raise ValueError("Missing the required parameter `identity_id` when calling `add_identity_to_user_group`")


        collection_formats = {}

        path_params = {}
        if 'user_group_id' in params:
            path_params['userGroupId'] = params['user_group_id']
        if 'identity_id' in params:
            path_params['identityId'] = params['identity_id']

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/usergroups/{userGroupId}/{identityId}', 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'UserGroupOutputV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def archive_user_group(self, **kwargs):
        """
        Archive a user group
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.archive_user_group(user_group_id=user_group_id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str user_group_id: ID of user group to archive (required)
        :param bool remove_permissions: Whether to remove permissions associated with the group being archived
        :return: UserGroupOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: UserGroupOutputV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.archive_user_group_with_http_info(**kwargs)
        else:
            (data) = self.archive_user_group_with_http_info(**kwargs)
            return data

    def archive_user_group_with_http_info(self, **kwargs):
        """
        Archive a user group
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.archive_user_group_with_http_info(user_group_id=user_group_id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str user_group_id: ID of user group to archive (required)
        :param bool remove_permissions: Whether to remove permissions associated with the group being archived
        :return: UserGroupOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: UserGroupOutputV1
        """

        all_params = ['user_group_id', 'remove_permissions']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method archive_user_group" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'user_group_id' is set
        if ('user_group_id' not in params) or (params['user_group_id'] is None):
            raise ValueError("Missing the required parameter `user_group_id` when calling `archive_user_group`")


        collection_formats = {}

        path_params = {}
        if 'user_group_id' in params:
            path_params['userGroupId'] = params['user_group_id']

        query_params = []
        if 'remove_permissions' in params:
            query_params.append(('removePermissions', params['remove_permissions']))

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/usergroups/{userGroupId}/archive', 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'UserGroupOutputV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def create_user_group(self, **kwargs):
        """
        Create a user group hosted within Seeq
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.create_user_group(body=body_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param UserGroupInputV1 body: User group information (required)
        :return: UserGroupOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: UserGroupOutputV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.create_user_group_with_http_info(**kwargs)
        else:
            (data) = self.create_user_group_with_http_info(**kwargs)
            return data

    def create_user_group_with_http_info(self, **kwargs):
        """
        Create a user group hosted within Seeq
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.create_user_group_with_http_info(body=body_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param UserGroupInputV1 body: User group information (required)
        :return: UserGroupOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: UserGroupOutputV1
        """

        all_params = ['body']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_user_group" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `create_user_group`")


        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/usergroups', 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'UserGroupOutputV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def disable_user_group(self, **kwargs):
        """
        Disable a user group
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.disable_user_group(user_group_id=user_group_id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str user_group_id: ID of user group to disable (required)
        :param bool remove_permissions: Whether to remove permissions associated with the group being disabled
        :return: UserGroupOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: UserGroupOutputV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.disable_user_group_with_http_info(**kwargs)
        else:
            (data) = self.disable_user_group_with_http_info(**kwargs)
            return data

    def disable_user_group_with_http_info(self, **kwargs):
        """
        Disable a user group
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.disable_user_group_with_http_info(user_group_id=user_group_id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str user_group_id: ID of user group to disable (required)
        :param bool remove_permissions: Whether to remove permissions associated with the group being disabled
        :return: UserGroupOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: UserGroupOutputV1
        """

        all_params = ['user_group_id', 'remove_permissions']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method disable_user_group" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'user_group_id' is set
        if ('user_group_id' not in params) or (params['user_group_id'] is None):
            raise ValueError("Missing the required parameter `user_group_id` when calling `disable_user_group`")


        collection_formats = {}

        path_params = {}
        if 'user_group_id' in params:
            path_params['userGroupId'] = params['user_group_id']

        query_params = []
        if 'remove_permissions' in params:
            query_params.append(('removePermissions', params['remove_permissions']))

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/usergroups/{userGroupId}/disable', 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'UserGroupOutputV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def get_user_group(self, **kwargs):
        """
        Get a user group
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_user_group(user_group_id=user_group_id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str user_group_id: ID of the user group to get (required)
        :return: UserGroupOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: UserGroupOutputV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.get_user_group_with_http_info(**kwargs)
        else:
            (data) = self.get_user_group_with_http_info(**kwargs)
            return data

    def get_user_group_with_http_info(self, **kwargs):
        """
        Get a user group
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_user_group_with_http_info(user_group_id=user_group_id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str user_group_id: ID of the user group to get (required)
        :return: UserGroupOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: UserGroupOutputV1
        """

        all_params = ['user_group_id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_user_group" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'user_group_id' is set
        if ('user_group_id' not in params) or (params['user_group_id'] is None):
            raise ValueError("Missing the required parameter `user_group_id` when calling `get_user_group`")


        collection_formats = {}

        path_params = {}
        if 'user_group_id' in params:
            path_params['userGroupId'] = params['user_group_id']

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/usergroups/{userGroupId}', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'UserGroupOutputV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def get_user_groups(self, **kwargs):
        """
        Get a collection of usergroups
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_user_groups(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str name_search: Search text by which to filter user groups' names.
        :param str datasource_id_search: Search text by which to filter user groups' directories.
        :param bool is_enabled: Whether to filter users to only users who are enabled.
        :param str sort_order: A field by which to order the user groups followed by a space and 'asc' or 'desc'. Field name can be one of: name, directory
        :param int offset: The pagination offset, the index of the first collection item that will be returned in this page of results
        :param int limit: The pagination level, the total number of collection items that will be returned in this page of results
        :return: IdentityPreviewListV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: IdentityPreviewListV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.get_user_groups_with_http_info(**kwargs)
        else:
            (data) = self.get_user_groups_with_http_info(**kwargs)
            return data

    def get_user_groups_with_http_info(self, **kwargs):
        """
        Get a collection of usergroups
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_user_groups_with_http_info(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str name_search: Search text by which to filter user groups' names.
        :param str datasource_id_search: Search text by which to filter user groups' directories.
        :param bool is_enabled: Whether to filter users to only users who are enabled.
        :param str sort_order: A field by which to order the user groups followed by a space and 'asc' or 'desc'. Field name can be one of: name, directory
        :param int offset: The pagination offset, the index of the first collection item that will be returned in this page of results
        :param int limit: The pagination level, the total number of collection items that will be returned in this page of results
        :return: IdentityPreviewListV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: IdentityPreviewListV1
        """

        all_params = ['name_search', 'datasource_id_search', 'is_enabled', 'sort_order', 'offset', 'limit']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_user_groups" % key
                )
            params[key] = val
        del params['kwargs']


        collection_formats = {}

        path_params = {}

        query_params = []
        if 'name_search' in params:
            query_params.append(('nameSearch', params['name_search']))
        if 'datasource_id_search' in params:
            query_params.append(('datasourceIdSearch', params['datasource_id_search']))
        if 'is_enabled' in params:
            query_params.append(('isEnabled', params['is_enabled']))
        if 'sort_order' in params:
            query_params.append(('sortOrder', params['sort_order']))
        if 'offset' in params:
            query_params.append(('offset', params['offset']))
        if 'limit' in params:
            query_params.append(('limit', params['limit']))

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/usergroups', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'IdentityPreviewListV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def put_user_groups(self, **kwargs):
        """
        Create or update multiple user groups
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.put_user_groups(body=body_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param PutUserGroupsInputV1 body: (required)
        :return: ItemBatchOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ItemBatchOutputV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.put_user_groups_with_http_info(**kwargs)
        else:
            (data) = self.put_user_groups_with_http_info(**kwargs)
            return data

    def put_user_groups_with_http_info(self, **kwargs):
        """
        Create or update multiple user groups
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.put_user_groups_with_http_info(body=body_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param PutUserGroupsInputV1 body: (required)
        :return: ItemBatchOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ItemBatchOutputV1
        """

        all_params = ['body']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method put_user_groups" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `put_user_groups`")


        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/usergroups/batch', 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'ItemBatchOutputV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def remove_identity_from_user_group(self, **kwargs):
        """
        Remove a user from a user group
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.remove_identity_from_user_group(user_group_id=user_group_id_value, identity_id=identity_id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str user_group_id: ID of the user group to remove user from (required)
        :param str identity_id: ID of the user or user group to remove. (required)
        :return: UserGroupOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: UserGroupOutputV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.remove_identity_from_user_group_with_http_info(**kwargs)
        else:
            (data) = self.remove_identity_from_user_group_with_http_info(**kwargs)
            return data

    def remove_identity_from_user_group_with_http_info(self, **kwargs):
        """
        Remove a user from a user group
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.remove_identity_from_user_group_with_http_info(user_group_id=user_group_id_value, identity_id=identity_id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str user_group_id: ID of the user group to remove user from (required)
        :param str identity_id: ID of the user or user group to remove. (required)
        :return: UserGroupOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: UserGroupOutputV1
        """

        all_params = ['user_group_id', 'identity_id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method remove_identity_from_user_group" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'user_group_id' is set
        if ('user_group_id' not in params) or (params['user_group_id'] is None):
            raise ValueError("Missing the required parameter `user_group_id` when calling `remove_identity_from_user_group`")
        # verify the required parameter 'identity_id' is set
        if ('identity_id' not in params) or (params['identity_id'] is None):
            raise ValueError("Missing the required parameter `identity_id` when calling `remove_identity_from_user_group`")


        collection_formats = {}

        path_params = {}
        if 'user_group_id' in params:
            path_params['userGroupId'] = params['user_group_id']
        if 'identity_id' in params:
            path_params['identityId'] = params['identity_id']

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/usergroups/{userGroupId}/{identityId}', 'DELETE',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'UserGroupOutputV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def remove_user_group(self, **kwargs):
        """
        Remove a user group
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.remove_user_group(user_group_id=user_group_id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str user_group_id: ID of the user group to remove (required)
        :return: StatusMessageBase
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: StatusMessageBase
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.remove_user_group_with_http_info(**kwargs)
        else:
            (data) = self.remove_user_group_with_http_info(**kwargs)
            return data

    def remove_user_group_with_http_info(self, **kwargs):
        """
        Remove a user group
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.remove_user_group_with_http_info(user_group_id=user_group_id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str user_group_id: ID of the user group to remove (required)
        :return: StatusMessageBase
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: StatusMessageBase
        """

        all_params = ['user_group_id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method remove_user_group" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'user_group_id' is set
        if ('user_group_id' not in params) or (params['user_group_id'] is None):
            raise ValueError("Missing the required parameter `user_group_id` when calling `remove_user_group`")


        collection_formats = {}

        path_params = {}
        if 'user_group_id' in params:
            path_params['userGroupId'] = params['user_group_id']

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/usergroups/{userGroupId}', 'DELETE',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'StatusMessageBase'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def update_user_group(self, **kwargs):
        """
        Update name or description of a user group
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.update_user_group(body=body_value, user_group_id=user_group_id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param UserGroupInputV1 body: New user group information (required)
        :param str user_group_id: ID of the user group to update (required)
        :return: UserGroupOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: UserGroupOutputV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.update_user_group_with_http_info(**kwargs)
        else:
            (data) = self.update_user_group_with_http_info(**kwargs)
            return data

    def update_user_group_with_http_info(self, **kwargs):
        """
        Update name or description of a user group
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.update_user_group_with_http_info(body=body_value, user_group_id=user_group_id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param UserGroupInputV1 body: New user group information (required)
        :param str user_group_id: ID of the user group to update (required)
        :return: UserGroupOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: UserGroupOutputV1
        """

        all_params = ['body', 'user_group_id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_user_group" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `update_user_group`")
        # verify the required parameter 'user_group_id' is set
        if ('user_group_id' not in params) or (params['user_group_id'] is None):
            raise ValueError("Missing the required parameter `user_group_id` when calling `update_user_group`")


        collection_formats = {}

        path_params = {}
        if 'user_group_id' in params:
            path_params['userGroupId'] = params['user_group_id']

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/usergroups/{userGroupId}', 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'UserGroupOutputV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 62.0.9-v202311011323
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class SwapOptionV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'invalid_swap_outs': 'list[InvalidSwapOutV1]',
        'items_with_swap_pairs': 'list[ItemWithSwapPairsV1]',
        'swap_root_candidate': 'ItemPreviewWithAssetsV1'
    }

    attribute_map = {
        'invalid_swap_outs': 'invalidSwapOuts',
        'items_with_swap_pairs': 'itemsWithSwapPairs',
        'swap_root_candidate': 'swapRootCandidate'
    }

    def __init__(self, invalid_swap_outs=None, items_with_swap_pairs=None, swap_root_candidate=None):
        """
        SwapOptionV1 - a model defined in Swagger
        """

        self._invalid_swap_outs = None
        self._items_with_swap_pairs = None
        self._swap_root_candidate = None

        if invalid_swap_outs is not None:
          self.invalid_swap_outs = invalid_swap_outs
        if items_with_swap_pairs is not None:
          self.items_with_swap_pairs = items_with_swap_pairs
        if swap_root_candidate is not None:
          self.swap_root_candidate = swap_root_candidate

    @property
    def invalid_swap_outs(self):
        """
        Gets the invalid_swap_outs of this SwapOptionV1.
        The list of items from the query parameters that are invalid for swapping out with root item

        :return: The invalid_swap_outs of this SwapOptionV1.
        :rtype: list[InvalidSwapOutV1]
        """
        return self._invalid_swap_outs

    @invalid_swap_outs.setter
    def invalid_swap_outs(self, invalid_swap_outs):
        """
        Sets the invalid_swap_outs of this SwapOptionV1.
        The list of items from the query parameters that are invalid for swapping out with root item

        :param invalid_swap_outs: The invalid_swap_outs of this SwapOptionV1.
        :type: list[InvalidSwapOutV1]
        """

        self._invalid_swap_outs = invalid_swap_outs

    @property
    def items_with_swap_pairs(self):
        """
        Gets the items_with_swap_pairs of this SwapOptionV1.
        The list of items from the query parameters that can be swapped, augmented with the swap pairs needed to perform the swap

        :return: The items_with_swap_pairs of this SwapOptionV1.
        :rtype: list[ItemWithSwapPairsV1]
        """
        return self._items_with_swap_pairs

    @items_with_swap_pairs.setter
    def items_with_swap_pairs(self, items_with_swap_pairs):
        """
        Sets the items_with_swap_pairs of this SwapOptionV1.
        The list of items from the query parameters that can be swapped, augmented with the swap pairs needed to perform the swap

        :param items_with_swap_pairs: The items_with_swap_pairs of this SwapOptionV1.
        :type: list[ItemWithSwapPairsV1]
        """

        self._items_with_swap_pairs = items_with_swap_pairs

    @property
    def swap_root_candidate(self):
        """
        Gets the swap_root_candidate of this SwapOptionV1.

        :return: The swap_root_candidate of this SwapOptionV1.
        :rtype: ItemPreviewWithAssetsV1
        """
        return self._swap_root_candidate

    @swap_root_candidate.setter
    def swap_root_candidate(self, swap_root_candidate):
        """
        Sets the swap_root_candidate of this SwapOptionV1.

        :param swap_root_candidate: The swap_root_candidate of this SwapOptionV1.
        :type: ItemPreviewWithAssetsV1
        """

        self._swap_root_candidate = swap_root_candidate

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, SwapOptionV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 62.0.9-v202311011323
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class ItemWithSwapPairsV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'item': 'ItemPreviewWithAssetsV1',
        'parameter_match': 'float',
        'swap_pairs': 'list[SwapInputV1]'
    }

    attribute_map = {
        'item': 'item',
        'parameter_match': 'parameterMatch',
        'swap_pairs': 'swapPairs'
    }

    def __init__(self, item=None, parameter_match=None, swap_pairs=None):
        """
        ItemWithSwapPairsV1 - a model defined in Swagger
        """

        self._item = None
        self._parameter_match = None
        self._swap_pairs = None

        if item is not None:
          self.item = item
        if parameter_match is not None:
          self.parameter_match = parameter_match
        if swap_pairs is not None:
          self.swap_pairs = swap_pairs

    @property
    def item(self):
        """
        Gets the item of this ItemWithSwapPairsV1.

        :return: The item of this ItemWithSwapPairsV1.
        :rtype: ItemPreviewWithAssetsV1
        """
        return self._item

    @item.setter
    def item(self, item):
        """
        Sets the item of this ItemWithSwapPairsV1.

        :param item: The item of this ItemWithSwapPairsV1.
        :type: ItemPreviewWithAssetsV1
        """
        if item is None:
            raise ValueError("Invalid value for `item`, must not be `None`")

        self._item = item

    @property
    def parameter_match(self):
        """
        Gets the parameter_match of this ItemWithSwapPairsV1.
        The ratio of matched to total parameters

        :return: The parameter_match of this ItemWithSwapPairsV1.
        :rtype: float
        """
        return self._parameter_match

    @parameter_match.setter
    def parameter_match(self, parameter_match):
        """
        Sets the parameter_match of this ItemWithSwapPairsV1.
        The ratio of matched to total parameters

        :param parameter_match: The parameter_match of this ItemWithSwapPairsV1.
        :type: float
        """
        if parameter_match is None:
            raise ValueError("Invalid value for `parameter_match`, must not be `None`")

        self._parameter_match = parameter_match

    @property
    def swap_pairs(self):
        """
        Gets the swap_pairs of this ItemWithSwapPairsV1.
        The list of swap pairs needed to perform the swap.

        :return: The swap_pairs of this ItemWithSwapPairsV1.
        :rtype: list[SwapInputV1]
        """
        return self._swap_pairs

    @swap_pairs.setter
    def swap_pairs(self, swap_pairs):
        """
        Sets the swap_pairs of this ItemWithSwapPairsV1.
        The list of swap pairs needed to perform the swap.

        :param swap_pairs: The swap_pairs of this ItemWithSwapPairsV1.
        :type: list[SwapInputV1]
        """
        if swap_pairs is None:
            raise ValueError("Invalid value for `swap_pairs`, must not be `None`")

        self._swap_pairs = swap_pairs

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ItemWithSwapPairsV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
